@@ -240,7 +240,7 @@ class Product(
                     order_method = TemplateFunction.order(attr)
                     setattr(cls, 'order_%s' % attr, order_method)
 
-    @fields.depends('template')
+    @fields.depends('template', '_parent_template.id')
     def on_change_template(self):
         for name, field in self._fields.items():
             if isinstance(field, TemplateFunction):
@@ -253,6 +253,9 @@ class Product(
     def get_template(self, name):
         value = getattr(self.template, name)
         if isinstance(value, Model):
+            field = getattr(self.__class__, name)
+            if field._type == 'reference':
+                return str(value)
             return value.id
         elif (isinstance(value, (list, tuple))
                 and value and isinstance(value[0], Model)):
